@@ -1,20 +1,7 @@
 /*
-    Copyright 2006-2008 by Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Robert Knight <robertknight@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -22,6 +9,9 @@
 
 // Qt
 #include <QMouseEvent>
+#include <QMenu>
+#include <QMenuBar>
+#include <QStatusBar>
 
 // KDE
 #include <KAcceleratorManager>
@@ -31,8 +21,7 @@
 #include <KLocalizedString>
 #include <KWindowEffects>
 
-#include <QMenu>
-#include <QMenuBar>
+
 #include <KMessageBox>
 #include <KStandardAction>
 #include <KStandardGuiItem>
@@ -140,7 +129,7 @@ MainWindow::MainWindow() :
     KAcceleratorManager::setNoAccel(menuBar());
 
     // create menus
-    createGUI();
+    setupGUI();
 
     // remember the original menu accelerators for later use
     rememberMenuAccelerators();
@@ -155,6 +144,12 @@ MainWindow::MainWindow() :
     applyKonsoleSettings();
     connect(KonsoleSettings::self(), &Konsole::KonsoleSettings::configChanged, this,
             &Konsole::MainWindow::applyKonsoleSettings);
+
+
+    // KXMLGui is making the status bar always visible, we need to fix in a proper way.
+    if (statusBar() != nullptr) {
+        statusBar()->installEventFilter(this);
+    }
 }
 
 void MainWindow::updateUseTransparency()
@@ -326,7 +321,7 @@ void MainWindow::setupActions()
     // File Menu
     _newTabMenuAction = new KActionMenu(QIcon::fromTheme(QStringLiteral("tab-new")),
                                         i18nc("@action:inmenu", "&New Tab"), collection);
-    collection->setDefaultShortcut(_newTabMenuAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_T);
+    collection->setDefaultShortcut(_newTabMenuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_T);
     collection->setShortcutsConfigurable(_newTabMenuAction, true);
     _newTabMenuAction->setAutoRepeat(false);
     connect(_newTabMenuAction, &KActionMenu::triggered, this, &MainWindow::newTab);
@@ -343,14 +338,14 @@ void MainWindow::setupActions()
     menuAction = collection->addAction(QStringLiteral("new-window"));
     menuAction->setIcon(QIcon::fromTheme(QStringLiteral("window-new")));
     menuAction->setText(i18nc("@action:inmenu", "New &Window"));
-    collection->setDefaultShortcut(menuAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_N);
+    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_N);
     menuAction->setAutoRepeat(false);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::newWindow);
 
     menuAction = collection->addAction(QStringLiteral("close-window"));
     menuAction->setIcon(QIcon::fromTheme(QStringLiteral("window-close")));
     menuAction->setText(i18nc("@action:inmenu", "Close Window"));
-    collection->setDefaultShortcut(menuAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_Q);
+    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_Q);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::close);
 
     // Bookmark Menu
@@ -362,7 +357,7 @@ void MainWindow::setupActions()
 
     // Settings Menu
     _toggleMenuBarAction = KStandardAction::showMenubar(menuBar(), &QMenuBar::setVisible, collection);
-    collection->setDefaultShortcut(_toggleMenuBarAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_M);
+    collection->setDefaultShortcut(_toggleMenuBarAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_M);
 
     // Full Screen
     menuAction = KStandardAction::fullScreen(this, &MainWindow::viewFullScreen, this, collection);
@@ -380,7 +375,7 @@ void MainWindow::setupActions()
     // Set up an shortcut-only action for activating menu bar.
     menuAction = collection->addAction(QStringLiteral("activate-menu"));
     menuAction->setText(i18nc("@item", "Activate Menu"));
-    collection->setDefaultShortcut(menuAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_F10);
+    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_F10);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::activateMenuBar);
 }
 
@@ -420,15 +415,20 @@ void MainWindow::profileListChanged(const QList<QAction *> &sessionActions)
         for (QAction *sessionAction : sessionActions) {
             _newTabMenuAction->menu()->addAction(sessionAction);
 
-            // NOTE: defaultProfile seems to not work here, sigh.
+            auto setActionFont = [sessionAction](bool isBold) {
+                QFont actionFont = sessionAction->font();
+                actionFont.setBold(isBold);
+                sessionAction->setFont(actionFont);
+            };
+
             Profile::Ptr profile = ProfileManager::instance()->defaultProfile();
             if (profile && profile->name() == sessionAction->text().remove(QLatin1Char('&'))) {
                 QIcon icon(KIconLoader::global()->loadIcon(profile->icon(), KIconLoader::Small, 0, KIconLoader::DefaultState, QStringList(QStringLiteral("emblem-favorite"))));
                 sessionAction->setIcon(icon);
-                _newTabMenuAction->menu()->setDefaultAction(sessionAction);
-                QFont actionFont = sessionAction->font();
-                actionFont.setBold(true);
-                sessionAction->setFont(actionFont);
+                setActionFont(true);
+            } else {
+                sessionAction->setIcon(QIcon::fromTheme(profile->icon()));
+                setActionFont(false);
             }
         }
     } else {
@@ -552,7 +552,7 @@ void MainWindow::setFocus()
 void MainWindow::newWindow()
 {
     Profile::Ptr defaultProfile = ProfileManager::instance()->defaultProfile();
-    emit newWindowRequest(defaultProfile, activeSessionDir());
+    Q_EMIT newWindowRequest(defaultProfile, activeSessionDir());
 }
 
 bool MainWindow::queryClose()
@@ -566,13 +566,9 @@ bool MainWindow::queryClose()
 
     // Check what processes are running, excluding the shell
     QStringList processesRunning;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     // Need to make a local copy so the begin() and end() point to the same QList
     const QList<Session*> sessionList = _viewManager->sessions();
     const QSet<Session*> uniqueSessions(sessionList.begin(), sessionList.end());
-#else
-    const QSet<Session*> uniqueSessions = QSet<Session*>::fromList(_viewManager->sessions());
-#endif
 
     for (Session *session : uniqueSessions) {
         if ((session == nullptr) || !session->isForegroundProcessActive()) {
@@ -944,7 +940,13 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event)
             default: ;
         }
     }
-
+    if (qobject_cast<QStatusBar*>(obj) != nullptr) {
+        switch(event->type()) {
+            case QEvent::Show: statusBar()->hide(); break;
+            default: return true;
+        }
+        return true;
+    }
     return KXmlGuiWindow::eventFilter(obj, event);
 }
 
