@@ -1,23 +1,8 @@
 /*
-    This file is part of Konsole, an X terminal.
+    SPDX-FileCopyrightText: 2007-2008 Robert Knight <robert.knight@gmail.com>
+    SPDX-FileCopyrightText: 1997, 1998 Lars Doelle <lars.doelle@on-line.de>
 
-    Copyright 2007-2008 by Robert Knight <robert.knight@gmail.com>
-    Copyright 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -111,7 +96,7 @@ void Vt102Emulation::reset()
         setCodec(LocaleCodec);
     }
 
-    emit resetCursorStyleRequest();
+    Q_EMIT resetCursorStyleRequest();
 
     bufferedUpdate();
 }
@@ -235,7 +220,7 @@ constexpr int token_csi_psp(int a, int n)
     return token_construct(12, a, n);
 }
 
-const int MAX_ARGUMENT = 4096;
+const int MAX_ARGUMENT = 40960;
 
 // Tokenizer --------------------------------------------------------------- --
 
@@ -256,9 +241,7 @@ void Vt102Emulation::resetTokenizer()
 
 void Vt102Emulation::addDigit(int digit)
 {
-    if (argv[argc] < MAX_ARGUMENT) {
-        argv[argc] = 10 * argv[argc] + digit;
-    }
+    argv[argc] = qMin(10 * argv[argc] + digit, MAX_ARGUMENT);
 }
 
 void Vt102Emulation::addArgument()
@@ -405,7 +388,7 @@ void Vt102Emulation::receiveChar(uint cc)
           // This runs two times per link, the first prepares the link to be read,
           // the second finalizes it.
           if (s[2] == XTERM_EXTENDED::URL_LINK) {
-                // printf '\e]8;;http://example.com\e\\This is a link\e]8;;\e\\\n'
+                // printf '\e]8;;https://example.com\e\\This is a link\e]8;;\e\\\n'
                _currentScreen->urlExtractor()->toggleUrlInput();
           }
           processSessionAttributeRequest(p-1);
@@ -534,7 +517,7 @@ void Vt102Emulation::processSessionAttributeRequest(int tokenSize)
   if (value == QLatin1String("?")) {
       // pass terminator type indication here, because OSC response terminator
       // should match the terminator of OSC request.
-      emit sessionAttributeRequest(attribute, tokenBuffer[tokenSize]);
+      Q_EMIT sessionAttributeRequest(attribute, tokenBuffer[tokenSize]);
       return;
   }
 
@@ -547,7 +530,7 @@ void Vt102Emulation::updateSessionAttributes()
     QListIterator<int> iter(_pendingSessionAttributesUpdates.keys());
     while (iter.hasNext()) {
         int arg = iter.next();
-        emit sessionAttributeChanged(arg , _pendingSessionAttributesUpdates[arg]);
+        Q_EMIT sessionAttributeChanged(arg , _pendingSessionAttributesUpdates[arg]);
     }
     _pendingSessionAttributesUpdates.clear();
 }
@@ -586,7 +569,7 @@ void Vt102Emulation::processToken(int token, int p, int q)
     case token_ctl('D'      ) : /* EOT: ignored                      */ break;
     case token_ctl('E'      ) :      reportAnswerBack     (          ); break; //VT100
     case token_ctl('F'      ) : /* ACK: ignored                      */ break;
-    case token_ctl('G'      ) : emit bell();
+    case token_ctl('G'      ) : Q_EMIT bell();
                                 break; //VT100
     case token_ctl('H'      ) : _currentScreen->backspace            (          ); break; //VT100
     case token_ctl('I'      ) : _currentScreen->tab                  (          ); break; //VT100
@@ -670,11 +653,11 @@ void Vt102Emulation::processToken(int token, int p, int q)
 
 // resize = \e[8;<row>;<col>t
     case token_csi_ps('t',   8) : setImageSize( p /*lines */, q /* columns */ );
-                               emit imageResizeRequest(QSize(q, p));
+                               Q_EMIT imageResizeRequest(QSize(q, p));
                                break;
 
 // change tab text color : \e[28;<color>t  color: 0-16,777,215
-    case token_csi_ps('t',   28) : emit changeTabTextColorRequest      ( p        );          break;
+    case token_csi_ps('t',   28) : Q_EMIT changeTabTextColorRequest      ( p        );          break;
 
     case token_csi_ps('K',   0) : _currentScreen->clearToEndOfLine     (          ); break;
     case token_csi_ps('K',   1) : _currentScreen->clearToBeginOfLine   (          ); break;
@@ -942,14 +925,14 @@ void Vt102Emulation::processToken(int token, int p, int q)
     // Set Cursor Style (DECSCUSR), VT520, with the extra xterm sequences
     // the first one is a special case, 'ESC[ q', which mimics 'ESC[1 q'
     // Using 0 to reset to default is matching VTE, but not any official standard.
-    case token_csi_sp ('q'    ) : emit setCursorStyleRequest(Enum::BlockCursor,     true);  break;
-    case token_csi_psp('q',  0) : emit resetCursorStyleRequest();                           break;
-    case token_csi_psp('q',  1) : emit setCursorStyleRequest(Enum::BlockCursor,     true);  break;
-    case token_csi_psp('q',  2) : emit setCursorStyleRequest(Enum::BlockCursor,     false); break;
-    case token_csi_psp('q',  3) : emit setCursorStyleRequest(Enum::UnderlineCursor, true);  break;
-    case token_csi_psp('q',  4) : emit setCursorStyleRequest(Enum::UnderlineCursor, false); break;
-    case token_csi_psp('q',  5) : emit setCursorStyleRequest(Enum::IBeamCursor,     true);  break;
-    case token_csi_psp('q',  6) : emit setCursorStyleRequest(Enum::IBeamCursor,     false); break;
+    case token_csi_sp ('q'    ) : Q_EMIT setCursorStyleRequest(Enum::BlockCursor,     true);  break;
+    case token_csi_psp('q',  0) : Q_EMIT resetCursorStyleRequest();                           break;
+    case token_csi_psp('q',  1) : Q_EMIT setCursorStyleRequest(Enum::BlockCursor,     true);  break;
+    case token_csi_psp('q',  2) : Q_EMIT setCursorStyleRequest(Enum::BlockCursor,     false); break;
+    case token_csi_psp('q',  3) : Q_EMIT setCursorStyleRequest(Enum::UnderlineCursor, true);  break;
+    case token_csi_psp('q',  4) : Q_EMIT setCursorStyleRequest(Enum::UnderlineCursor, false); break;
+    case token_csi_psp('q',  5) : Q_EMIT setCursorStyleRequest(Enum::IBeamCursor,     true);  break;
+    case token_csi_psp('q',  6) : Q_EMIT setCursorStyleRequest(Enum::IBeamCursor,     false); break;
 
     //FIXME: weird DEC reset sequence
     case token_csi_pe('p'      ) : /* IGNORED: reset         (        ) */ break;
@@ -991,7 +974,7 @@ void Vt102Emulation::clearScreenAndSetColumns(int columnCount)
 
 void Vt102Emulation::sendString(const QByteArray& s)
 {
-    emit sendData(s);
+    Q_EMIT sendData(s);
 }
 
 void Vt102Emulation::reportCursorPosition()
@@ -1177,11 +1160,11 @@ void Vt102Emulation::sendKeyEvent(QKeyEvent *event)
         if ((modifiers &Qt::ControlModifier) != 0U) {
             switch (event->key()) {
             case Qt::Key_S:
-                emit flowControlKeyPressed(true);
+                Q_EMIT flowControlKeyPressed(true);
                 break;
             case Qt::Key_Q:
             case Qt::Key_C: // cancel flow control
-                emit flowControlKeyPressed(false);
+                Q_EMIT flowControlKeyPressed(false);
                 break;
             }
         }
@@ -1245,7 +1228,7 @@ void Vt102Emulation::sendKeyEvent(QKeyEvent *event)
         }
 
         if (!isReadOnly) {
-            emit sendData(textToSend);
+            Q_EMIT sendData(textToSend);
         }
     } else {
         if (!isReadOnly) {
@@ -1429,14 +1412,14 @@ void Vt102Emulation::setMode(int m)
     case MODE_Mouse1001:
     case MODE_Mouse1002:
     case MODE_Mouse1003:
-        emit programRequestsMouseTracking(true);
+        Q_EMIT programRequestsMouseTracking(true);
         break;
     case MODE_Mouse1007:
-        emit enableAlternateScrolling(true);
+        Q_EMIT enableAlternateScrolling(true);
         break;
 
     case MODE_BracketedPaste:
-        emit programBracketedPasteModeChanged(true);
+        Q_EMIT programBracketedPasteModeChanged(true);
         break;
 
     case MODE_AppScreen:
@@ -1466,14 +1449,14 @@ void Vt102Emulation::resetMode(int m)
     case MODE_Mouse1001:
     case MODE_Mouse1002:
     case MODE_Mouse1003:
-        emit programRequestsMouseTracking(false);
+        Q_EMIT programRequestsMouseTracking(false);
         break;
     case MODE_Mouse1007:
-        emit enableAlternateScrolling(false);
+        Q_EMIT enableAlternateScrolling(false);
         break;
 
     case MODE_BracketedPaste:
-        emit programBracketedPasteModeChanged(false);
+        Q_EMIT programBracketedPasteModeChanged(false);
         break;
 
     case MODE_AppScreen:
@@ -1481,8 +1464,8 @@ void Vt102Emulation::resetMode(int m)
         setScreen(0);
         break;
     }
-    // FIXME: Currently this has a redundant condition as MODES_SCREEN is 6
-    // and MODE_NewLine is 5
+    // FIXME: Currently this has a redundant condition as MODES_SCREEN is 7
+    // MODE_AppScreen is 6 and MODE_NewLine is 5
     if (m < MODES_SCREEN || m == MODE_NewLine) {
         _screen[0]->resetMode(m);
         _screen[1]->resetMode(m);
